@@ -22,7 +22,7 @@ char *styfile,*idxfile[256],indfile[256],*dicfile,logfile[256];
 KpathseaSupportInfo kp_ist,kp_dict;
 #endif
 
-#define VERSION "version 2.5a [3-Jun-2004]"
+#define VERSION "version 2.6a [10-Mar-2005]"
 
 main(argc,argv)
 int argc;
@@ -31,6 +31,7 @@ char **argv;
 	int i,j,k,cc,dd,startpagenum,ecount=0;
 	char buff[256],*envbuff;
 	FILE *fp;
+	char *convcode();
 
 #ifdef KPATHSEA
 	KP_init(argv[0]);
@@ -50,12 +51,10 @@ char **argv;
 		if ((argv[i][0]=='-')&&(strlen(argv[i])>=2)) {
 			switch (argv[i][1]) {
 			case 'c':
-Fprintf("option \'c\'.\n");
 				bcomp=1;
 				break;
 
 			case 'd':
-Fprintf("option \'d\'.\n");
 				if ((argv[i][2]=='\0')&&(i+1<argc)) {
 					i++;
 					dicfile=malloc(strlen(argv[i])+1);
@@ -68,27 +67,22 @@ Fprintf("option \'d\'.\n");
 				break;
 
 			case 'f':
-Fprintf("option \'f\'.\n");
 				force=1;
 				break;
 
 			case 'g':
-Fprintf("option \'g\'.\n");
 				gflg=1;
 				break;
 
 			case 'i':
-Fprintf("option \'i\'.\n");
 				fsti=1;
 				break;
 
 			case 'l':
-Fprintf("option \'l\'.\n");
 				lorder=1;
 				break;
 
 			case 'o':
-Fprintf("option \'o\'.\n");
 				if ((argv[i][2]=='\0')&&(i+1<argc)) {
 					strcpy(indfile,argv[++i]);
 				}
@@ -98,7 +92,6 @@ Fprintf("option \'o\'.\n");
 				break;
 
 			case 'p':
-Fprintf("option \'p\'.\n");
 				if ((argv[i][2]=='\0')&&(i+1<argc)) {
 					i++;
 					if (strcmp(argv[i],"any")==0) fpage=2;
@@ -121,12 +114,10 @@ Fprintf("option \'p\'.\n");
 				break;
 
 			case 'q':
-Fprintf("option \'q\'.\n");
 				verb=0;
 				break;
 
 			case 't':
-Fprintf("option \'t\'.\n");
 				if ((argv[i][2]=='\0')&&(i+1<argc)) {
 					strcpy(logfile,argv[++i]);
 				}
@@ -136,12 +127,10 @@ Fprintf("option \'t\'.\n");
 				break;
 
 			case 'r':
-Fprintf("option \'r\'.\n");
 				prange=0;
 				break;
 
 			case 's':
-Fprintf("option \'s\'.\n");
 				if ((argv[i][2]=='\0')&&(i+1<argc)) {
 					i++;
 					styfile=malloc(strlen(argv[i])+1);
@@ -155,35 +144,47 @@ Fprintf("option \'s\'.\n");
 
 			case 'v':
 				debug=1;
-Fprintf("option \'v\'.\n");
+				break;
+
+			case 'E':
+				kanji=Euc;
+				break;
+
+			case 'J':
+				kanji=Jis;
+				break;
+
+			case 'S':
+				kanji=Sjis;
 				break;
 
 			default:
-Fprintf("bad option.\n");
 				fprintf(stderr,"mendex - Japanese index processor, %s.\n",VERSION);
-				fprintf(stderr," Copyright 1995-2004 ASCII Corp.(www-ptex@ascii.co.jp)\n");
+				fprintf(stderr," Copyright 1995-2005 ASCII Corp.(www-ptex@ascii.co.jp)\n");
 				fprintf(stderr,"usage:\n");
 				fprintf(stderr,"%% mendex [-ilqrcg] [-s sty] [-d dic] [-o ind] [-t log] [-p no] [idx0 idx1 ...]\n");
 				fprintf(stderr,"options:\n");
-				fprintf(stderr,"-i	use stdin as the input file.\n");
-				fprintf(stderr,"-l	use letter ordering.\n");
-				fprintf(stderr,"-q	quiet mode.\n");
-				fprintf(stderr,"-r	disable implicit page formation.\n");
-				fprintf(stderr,"-c	compress blanks. (ignore leading and trailing blanks.)\n");
-				fprintf(stderr,"-g	make Japanese index head <%s>.\n",AKASATANA);
-				fprintf(stderr,"-f	force to output kanji.\n");
-				fprintf(stderr,"-s sty	take sty as style file.\n");
-				fprintf(stderr,"-d dic	take dic as dictionary file.\n");
-				fprintf(stderr,"-o ind	take ind as the output index file.\n");
-				fprintf(stderr,"-t log	take log as the error log file.\n");
-				fprintf(stderr,"-p no	set the starting page number of index.\n");
-				fprintf(stderr,"idx...	input files.\n");
+				fprintf(stderr,"-i      use stdin as the input file.\n");
+				fprintf(stderr,"-l      use letter ordering.\n");
+				fprintf(stderr,"-q      quiet mode.\n");
+				fprintf(stderr,"-r      disable implicit page formation.\n");
+				fprintf(stderr,"-c      compress blanks. (ignore leading and trailing blanks.)\n");
+				fprintf(stderr,"-g      make Japanese index head <%s>.\n",convcode(AKASATANA));
+				fprintf(stderr,"-f      force to output kanji.\n");
+				fprintf(stderr,"-s sty  take sty as style file.\n");
+				fprintf(stderr,"-d dic  take dic as dictionary file.\n");
+				fprintf(stderr,"-o ind  take ind as the output index file.\n");
+				fprintf(stderr,"-t log  take log as the error log file.\n");
+				fprintf(stderr,"-p no   set the starting page number of index.\n");
+				fprintf(stderr,"-E      EUC mode.\n");
+				fprintf(stderr,"-J      JIS mode.\n");
+				fprintf(stderr,"-S      ShiftJIS mode.\n");
+				fprintf(stderr,"idx...  input files.\n");
 				exit(0);
 				break;
 			}
 		}
 		else {
-Fprintf("idx file.\n");
 			cc=strlen(argv[i]);
 			if (cc<4) cc+=4;
 			else if (strcmp(&argv[i][cc-4],".idx")) cc+=4;
@@ -194,7 +195,6 @@ Fprintf("idx file.\n");
 	idxcount=j+fsti;
 
 /*   check option errors   */
-Fprintf("check option errors.\n");
 
 	if (idxcount==0) idxcount=fsti=1;
 
@@ -217,7 +217,6 @@ Fprintf("check option errors.\n");
 	if (styfile!=NULL) styread(styfile);
 
 	if ((indfile[0]=='\0')&&(idxcount-fsti>0)) {
-Fprintf("make ind file.\n");
 		for (i=strlen(idxfile[0]);i>=0;i--) {
 			if (idxfile[0][i]=='.') {
 				strncpy(indfile,idxfile[0],i);
@@ -229,7 +228,6 @@ Fprintf("make ind file.\n");
 	}
 
 	if (logfile[0]=='\0') {
-Fprintf("make log file.\n");
 		if (idxcount-fsti>0) {
 			for (i=strlen(idxfile[0]);i>=0;i--) {
 				if (idxfile[0][i]=='.') {
@@ -256,8 +254,11 @@ Fprintf("make log file.\n");
 	}
 	if (efp!=stderr) fprintf(efp,"This is mendex %s.\n",VERSION);
 
+/*   init kanatable   */
+
+	initkanatable();
+
 /*   read dictionary   */
-Fprintf("read dictionary.\n");
 
 	ecount+=dicread(dicfile);
 
@@ -287,7 +288,6 @@ Fprintf("read dictionary.\n");
 
 /*   read idx file   */
 
-Fprintf("read idx file.\n");
 	lines=0;
 	ecount=0;
 	ind=(struct index *)malloc(sizeof(struct index));
@@ -299,34 +299,18 @@ Fprintf("read idx file.\n");
 		ecount+=idxread(NULL,lines);
 	}
 	if (verb!=0) {
-		if (acc==0)
-			fprintf(stderr,"no entry accepted.\n",acc);
-		else if (lines==1)
-			fprintf(stderr,"1 entry accepted.\n",acc);
-		else
-			fprintf(stderr,"%d entries accepted.\n",acc);
+		fprintf(stderr,"%d entries accepted, %d rejected.\n",acc,reject);
 	}
 	if (efp!=stderr) {
-		if (lines==0)
-			fprintf(efp,"no entry accepted.\n",acc);
-		else if (lines==1)
-			fprintf(efp,"1 entry accepted.\n",acc);
-		else
-			fprintf(efp,"%d entries accepted.\n",acc);
+		fprintf(efp,"%d entries accepted, %d rejected.\n",acc,reject);
 	}
 
 	if (ecount!=0) {
 		if (verb!=0) {
-			if (ecount==1)
-				fprintf(stderr,"1 error, written in %s.\n",logfile);
-			else
-				fprintf(stderr,"%d errors, written in %s.\n",ecount,logfile);
+			fprintf(stderr,"%d errors, written in %s.\n",ecount,logfile);
 		}
 		if (efp!=stderr) {
-			if (ecount==1)
-				fprintf(efp,"1 error.\n");
-			else
-				fprintf(efp,"%d errors.\n",ecount);
+			fprintf(efp,"%d errors.\n",ecount);
 		}
 		lines=0;
 	}
@@ -350,20 +334,10 @@ Fprintf("read idx file.\n");
 	wsort(ind,lines);
 
 	if (verb!=0) {
-		if (scount==0)
-			fprintf(stderr,"...done(no comparison).\n");
-		else if (scount==1)
-			fprintf(stderr,"...done(1 comparison).\n");
-		else
-			fprintf(stderr,"...done(%d comparisons).\n",scount);
+		fprintf(stderr,"...done(%d comparisons).\n",scount);
 	}
 	if (efp!=stderr) {
-		if (scount==0)
-			fprintf(efp,"...done(no comparison).\n");
-		else if (scount==1)
-			fprintf(efp,"...done(1 comparison).\n");
-		else
-			fprintf(efp,"...done(%d comparisons).\n",scount);
+		fprintf(efp,"...done(%d comparisons).\n",scount);
 	}
 
 /*   sort pages   */
@@ -376,20 +350,10 @@ Fprintf("read idx file.\n");
 
 
 	if (verb!=0) {
-		if (scount==0)
-			fprintf(stderr,"...done(no comparison).\n");
-		else if (scount==1)
-			fprintf(stderr,"...done(1 comparison).\n");
-		else
-			fprintf(stderr,"...done(%d comparisons).\n",scount);
+		fprintf(stderr,"...done(%d comparisons).\n",scount);
 	}
 	if (efp!=stderr) {
-		if (scount==0)
-			fprintf(efp,"...done(no comparison).\n");
-		else if (scount==1)
-			fprintf(efp,"...done(1 comparison).\n");
-		else
-			fprintf(efp,"...done(%d comparisons).\n",scount);
+		fprintf(efp,"...done(%d comparisons).\n",scount);
 	}
 
 /*   get last page   */
@@ -428,22 +392,11 @@ Fprintf("read idx file.\n");
 	if (idxcount-fsti==0) strcpy(indfile,"stdout");
 
 	if (verb!=0) {
-		if (warn==0)
-			fprintf(stderr,"no warning, written in %s.\n",logfile);
-		else if (warn==1)
-			fprintf(stderr,"1 warning, written in %s.\n",logfile);
-		else
-			fprintf(stderr,"%d warnings, written in %s.\n",warn,logfile);
+		fprintf(stderr,"%d warnings, written in %s.\n",warn,logfile);
 		fprintf(stderr,"Output written in %s.\n",indfile);
 	}
 	if (efp!=stderr) {
-		if (warn==0)
-			fprintf(efp,"no warning, written in %s.\n",logfile);
-		else if (warn==1)
-			fprintf(efp,"1 warning, written in %s.\n",logfile);
-		else
-			fprintf(efp,"%d warnings, written in %s.\n",warn,logfile);
-
+		fprintf(efp,"%d warnings, written in %s.\n",warn,logfile);
 		fprintf(efp,"Output written in %s.\n",indfile);
 		fclose(efp);
 	}
